/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *   * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 */

package org.wso2.registry.ui.actions;

import com.opensymphony.xwork2.ActionContext;
import com.opensymphony.xwork2.ActionSupport;
import org.apache.struts2.StrutsStatics;
import org.wso2.registry.RegistryConstants;
import org.wso2.registry.secure.SecureRegistry;
import org.wso2.registry.jdbc.JDBCRegistry;
import org.wso2.registry.ui.WebAppConstants;
import org.wso2.usermanager.Realm;

import javax.servlet.ServletContext;
import javax.servlet.http.HttpServletRequest;

public class LoginAction extends AbstractRegistryAction {

    /**
     * Users can login from any page. So we need to store the URL of the user's previous page in the
     * LoginAction. Then after sucessful login users can be directed to thier pervious page.
     */
    private String actionName;
    private String path;

    private String userName;
    private String password;

    public String execute() throws Exception {

        ActionContext actionContext = ActionContext.getContext();
        HttpServletRequest request =
                (HttpServletRequest) actionContext.get(StrutsStatics.HTTP_REQUEST);
        ServletContext context = (ServletContext) actionContext.get(StrutsStatics.SERVLET_CONTEXT);
        JDBCRegistry jdbcRegistry = (JDBCRegistry) context.getAttribute(RegistryConstants.REGISTRY);

        // todo: authenticate the user

        Realm realm = (Realm) request.getSession().getServletContext().
                                        getAttribute(RegistryConstants.REGISTRY_REALM);

        SecureRegistry secureRegistry = new SecureRegistry(userName, password, jdbcRegistry, realm);

        request.getSession().setAttribute(WebAppConstants.USER_REGISTRY, secureRegistry);

        return ActionSupport.SUCCESS;
    }

    public String getActionName() {
        return actionName;
    }

    public void setActionName(String actionName) {
        this.actionName = actionName;
    }

    public String getPath() {
        return path;
    }

    public void setPath(String path) {
        this.path = path;
    }

    public String getUserName() {
        return userName;
    }

    public void setUserName(String userName) {
        this.userName = userName;
    }

    public String getPassword() {
        return password;
    }

    public void setPassword(String password) {
        this.password = password;
    }
}
